@@ -50,6 +50,11 @@ class Documentor(object):
 
             if name == 'binary':
                 faker_kwargs['length'] = 1024
+            elif name in ['zip', 'tar']:
+                faker_kwargs.update({
+                    'uncompressed_size': 1024,
+                    'min_file_size': 512,
+                })
 
             if with_args:
                 # retrieve all parameter
@@ -66,9 +71,9 @@ class Documentor(object):
                                 default = utils.quote(default)
                             else:
                                 # TODO check default type
-                                default = "{0}".format(default)
+                                default = "{}".format(default)
 
-                            arg = "{0}={1}".format(arg, default)
+                            arg = "{}={}".format(arg, default)
 
                         except IndexError:
                             pass
@@ -84,9 +89,7 @@ class Documentor(object):
                         arguments.append('**' + argspec.varkw)
 
             # build fake method signature
-            signature = "{0}{1}({2})".format(prefix,
-                                             name,
-                                             ", ".join(arguments))
+            signature = "{}{}({})".format(prefix, name, ", ".join(arguments))
 
             # make a fake example
             example = self.generator.format(name, *faker_args, **faker_kwargs)
