@@ -151,10 +151,15 @@ class BaseProvider(object):
             fixed length number
         """
         if digits is None:
-            digits = self.random_digit()
+            digits = self.random_digit_not_null()
+        if digits < 0:
+            raise ValueError("The digit parameter must be greater than or equal to 0.")
         if fix_len:
-            return self.generator.random.randint(
-                pow(10, digits - 1), pow(10, digits) - 1)
+            if digits > 0:
+                return self.generator.random.randint(
+                    pow(10, digits - 1), pow(10, digits) - 1)
+            else:
+                raise ValueError("A number of fixed length cannot have less than 1 digit in it.")
         else:
             return self.generator.random.randint(0, pow(10, digits) - 1)
 
