@@ -5,7 +5,7 @@ from __future__ import unicode_literals
 import re
 
 from calendar import timegm
-from datetime import timedelta, MAXYEAR
+from datetime import MAXYEAR, timedelta
 
 from dateutil import relativedelta
 from dateutil.tz import tzlocal, tzutc
@@ -41,7 +41,7 @@ class ParseError(ValueError):
 timedelta_pattern = r''
 for name, sym in [('years', 'y'), ('months', 'M'), ('weeks', 'w'), ('days', 'd'),
                   ('hours', 'h'), ('minutes', 'm'), ('seconds', 's')]:
-    timedelta_pattern += r'((?P<{0}>(?:\+|-)\d+?){1})?'.format(name, sym)
+    timedelta_pattern += r'((?P<{}>(?:\+|-)\d+?){})?'.format(name, sym)
 
 
 class Provider(BaseProvider):
@@ -1510,7 +1510,7 @@ class Provider(BaseProvider):
             return timedelta(**time_params).total_seconds()
         if isinstance(value, (int, float)):
             return value
-        raise ParseError("Invalid format for timedelta '{0}'".format(value))
+        raise ParseError("Invalid format for timedelta '{}'".format(value))
 
     @classmethod
     def _parse_date_time(cls, value, tzinfo=None):
@@ -1526,7 +1526,7 @@ class Provider(BaseProvider):
             return datetime_to_timestamp(now + timedelta(**time_params))
         if isinstance(value, int):
             return datetime_to_timestamp(now + timedelta(value))
-        raise ParseError("Invalid format for date '{0}'".format(value))
+        raise ParseError("Invalid format for date '{}'".format(value))
 
     @classmethod
     def _parse_date(cls, value):
@@ -1544,7 +1544,7 @@ class Provider(BaseProvider):
             return today + timedelta(**time_params)
         if isinstance(value, int):
             return today + timedelta(value)
-        raise ParseError("Invalid format for date '{0}'".format(value))
+        raise ParseError("Invalid format for date '{}'".format(value))
 
     def date_time_between(self, start_date='-30y', end_date='now', tzinfo=None):
         """
