@@ -1,7 +1,6 @@
 # coding=utf-8
 from __future__ import unicode_literals
 
-
 from .. import Provider as DateTimeProvider
 
 
@@ -28,7 +27,7 @@ class Provider(DateTimeProvider):
         '09': 'أيلول',
         '10': 'تشرين الأول',
         '11': 'تشرين الثاني',
-        '12': 'كانون الأول'
+        '12': 'كانون الأول',
     }
 
     centuries = [
