@@ -1,15 +1,17 @@
 # coding=utf-8
 
 from __future__ import unicode_literals
+
 from .. import Provider as InternetProvider
 
+
 class Provider(InternetProvider):
 
     free_email_domains = (
         'aol.de', 'gmail.com', 'gmx.de', 'googlemail.com', 'hotmail.de',
         'web.de', 'yahoo.de',
     )
-    tlds = ('com', 'com', 'com', 'net', 'org', 'de', 'de', 'de', )
+    tlds = ('com', 'com', 'com', 'net', 'org', 'de', 'de', 'de')
 
     replacements = (
         ('ä', 'ae'), ('Ä', 'Ae'),
